<template>
    <el-dialog
        title="审批"
        :visible.sync="visible"
        width="600px"
        :before-close="handleClose"
        append-to-body
        top="8vh"
    >
        <!--rejectForm.type 4 是整改模块，不需要其他选项-->
        <el-form
            v-form
            data-vv-scope="rejectForm"
            ref="rejectForm"
            :model="rejectForm"
            label-width="100px"
            :rules="rules"
        >
            <template v-if="startApproval">
                <el-row>
                    <el-row>
                        <el-col :span="24" v-if="rejectForm.goOn === 1">
                            <el-form-item label="审批节点" prop="auditName">
                                <el-select
                                    v-model="rejectForm.auditName"
                                    placeholder="请选择审批节点"
                                    clearable
                                >
                                    <el-option
                                        v-for="node in nodeList"
                                        :key="node"
                                        :label="node"
                                        :value="node"
                                    ></el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-col :span="24" v-if="rejectForm.goOn === 1">
                        <el-form-item label="审批人" prop="userName">
                            <eip-user-selector
                                v-model="rejectForm.userName"
                                append-to-body
                                :single="false"
                                :config="{
                                    id: 'rejectForm.userId',
                                    fullname: 'rejectForm.userName',
                                    account: 'rejectForm.userAccount',
                                }"
                                placeholder="请选择审核人"
                            />
                        </el-form-item>
                    </el-col>
                </el-row>
            </template>
            <template v-else-if="rejectForm.type !== 4 && rejectForm.status === 1">
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="是否继续审批" prop="goOn">
                            <el-radio-group v-model="rejectForm.goOn">
                                <el-radio :label="1">继续审批</el-radio>
                                <el-radio :label="0">结束审批</el-radio>
                            </el-radio-group>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24" v-if="rejectForm.goOn === 1">
                        <el-form-item label="审批节点" prop="auditName">
                            <el-select
                                v-model="rejectForm.auditName"
                                placeholder="请选择审批节点"
                                clearable
                            >
                                <el-option
                                    v-for="node in nodeList"
                                    :key="node"
                                    :label="node"
                                    :value="node"
                                ></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24" v-if="rejectForm.goOn === 1">
                        <el-form-item label="审批人" prop="userName">
                            <eip-user-selector
                                v-model="rejectForm.userName"
                                append-to-body
                                :single="false"
                                :config="{
                                    id: 'rejectForm.userId',
                                    fullname: 'rejectForm.userName',
                                    account: 'rejectForm.userAccount',
                                }"
                                placeholder="请选择审核人"
                            />
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="审批意见" prop="rejectReason">
                            <el-input
                                type="textarea"
                                v-model="rejectForm.rejectReason"
                                placeholder="请输入审批意见"
                                clearable
                            />
                        </el-form-item>
                    </el-col>
                </el-row>
            </template>
            <template v-else>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="审批意见" prop="rejectReason">
                            <el-input
                                type="textarea"
                                v-model="rejectForm.rejectReason"
                                placeholder="请输入审批意见"
                                clearable
                            />
                        </el-form-item>
                    </el-col>
                </el-row>
            </template>
        </el-form>
        <div slot="footer" class="dialog-footer">
            <el-button @click="handleClose">取 消</el-button>
            <el-button type="primary" @click="handleSubmit">确定</el-button>
        </div>
    </el-dialog>
</template>
<script>
import _ from 'lodash'
import eipUserSelector from '@/components/eipControl/selector/EipUserSelector.vue'

export default {
    name: 'QualitProcessReject',
    components: {
        eipUserSelector,
    },
    props: {
        startApproval: {
            type: Boolean,
            default: false,
        },
    },
    data() {
        return {
            visible: false,
            loading: false,
            rejectForm: {
                id: '',
                rejectReason: '',
                status: '',
                auditName: '',
                type: '',
                goOn: 1,
                userId: '',
                userName: '',
                userAccount: '',
            },
            nodeList: [],
            rules: {
                rejectReason: {
                    required: true,
                    message: '请输入审批意见',
                    trigger: 'change',
                },
                userName: {
                    required: true,
                    message: '请选择审批人',
                    trigger: 'blur',
                },
                auditName: {
                    required: true,
                    message: '请选择审批节点',
                    trigger: 'change',
                },
            },
            manageURL: '${yhxt}/bizRectificationCommon/v1/approve', //管理中心审核
        }
    },
    mounted() {},
    methods: {
        handleOpen(row, type, module) {
            if (!module && module !== 0) {
                this.$message({
                    message: '缺少必要参数module',
                    type: 'warning',
                })
                return
            }
            this.getNodeList(row.id)
            this.rejectForm.id = row.id
            this.rejectForm.status = type === true ? 1 : 2
            this.rejectForm.type = module
            this.visible = true
        },
        // 根据id 获取当前节点
        getNodeList(id) {
            if (!id) {
                this.$message({
                    message: '缺少必要参数id',
                    type: 'warning',
                })
                return
            }
            this.$http.get('${yhxt}/bizRectificationCommon/v1/node/' + id).then((res) => {
                if (res && res.data) {
                    this.nodeList = res.data
                }
            })
        },
        handleClose() {
            this.visible = false
            this.rejectForm = {
                id: '',
                rejectReason: '',
                status: '',
                auditName: '',
                type: '',
                goOn: 1,
                userId: '',
                userName: '',
                userAccount: '',
            }
        },
        handleSubmit() {
            this.$refs.rejectForm.validate((bool) => {
                if (bool) {
                    let dataSubmit = _.cloneDeep(this.rejectForm)

                    if (dataSubmit.goOn === 0) {
                        dataSubmit.auditName = ''
                        dataSubmit.userId = ''
                        dataSubmit.userName = ''
                        dataSubmit.userAccount = ''
                        dataSubmit.status = 0
                    }

                    let type = '发起审批'
                    if (!this.startApproval) {
                        if (dataSubmit.status === 2) {
                            type = '驳回'
                        } else if (dataSubmit.status === 0) {
                            type = '结束审批'
                        } else if (dataSubmit.status === 1) {
                            type = '通过审批'
                        }
                    }

                    delete dataSubmit.goOn
                    console.log('dataSubmit', dataSubmit)

                    this.$confirm(`确定${type}吗？`, '提示', {
                        confirmButtonText: '确定',
                        cancelButtonText: '取消',
                        type: 'warning',
                    }).then(() => {
                        this.$http.post(this.manageURL, dataSubmit).then((res) => {
                            if (res.data.state) {
                                this.$message({
                                    message: `${type}成功`,
                                    type: 'success',
                                })
                            }
                            this.$emit('reload')
                            this.handleClose()
                        })
                    })
                }
            })
        },
    },
}
</script>
<style lang="scss" scoped>

/deep/ .el-input input{
    height: 33px!important;
    line-height: 33px!important;
}
</style>
